Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3078)

Unified Diff: chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h

Issue 1890583002: Renaming App List Shower to App List Presenter (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h
diff --git a/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h b/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h
index f51bb83750cce763d3917b80e69671882478cdb0..39d998f895c5ff107ca9f20a653b97784db81fdc 100644
--- a/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h
+++ b/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h
@@ -8,19 +8,19 @@
#include "base/macros.h"
namespace app_list {
-class AppListShowerImpl;
+class AppListPresenterImpl;
class AppListView;
class AppsGridView;
class StartPageView;
}
// Accesses private data from an AppListServiceAsh and AppListShowerImpl
// for testing.
class AppListServiceAshTestApi {
public:
AppListServiceAshTestApi();
- app_list::AppListShowerImpl* GetAppListShower() const;
+ app_list::AppListPresenterImpl* GetAppListPresenter() const;
app_list::AppListView* GetAppListView() const;

Powered by Google App Engine
@@ -8,19 +8,19 @@
class StartPageView;
}
-// Accesses private data from an AppListServiceAsh and AppListShowerImpl
+// Accesses private data from an AppListServiceAsh and AppListPresenterImpl
// for testing.
class AppListServiceAshTestApi {
This is Rietveld 408576698